Learn R Programming

pempi (version 1.0.0)

covid19_austria: COVID-19 Data from Statistics Austria

Description

Data collected in Austria in 2020 (see e.g. SORA, 2020; Kowarik et al., 2021, for more details), allowing to estimate COVID-19 prevalence.

Usage

covid19_austria

Arguments

Format

A matrix with 2290 rows and 3 variables:

Y

Binary variable, 1 if participant i is tested positive in the survey sample, 0 otherwise.

Z

Binary variable, 1 if participant i was declared positive with the official procedure, 0 otherwise.

weights

Sampling weights.