Compute joint probabilities of P(W = j, Y = k) for j, k = 0, 1.
Arguments
- theta
A
numericthat provides the true prevalence of a given disease.- pi0
A
numericthat provides the prevalence or proportion of people (in the whole population) who are positive, as measured through a non-random, but systematic sampling (e.g. based on medical selection).- alpha
A
numericthat provides the False Negative (FN) rate for the sample R.- beta
A
numericthat provides the False Positive (FP) rate for the sample R.- alpha0
A
numericthat corresponds to the probability that a random participant has been incorrectly declared positive through the nontransparent procedure. In most applications, this probability is likely very close to zero.